%%% 游戏系统记录定义
%%% Created: 2025-02-21 05:01:23 UTC
%%% Author: SisMaker

%% 游戏状态记录
-record(game_state, {
    players = [],          % [{Pid, Cards, Role}]
    current_player,        % Pid
    last_play = [],        % {Pid, Cards}
    played_cards = [],     % [{Pid, Cards}]
    stage = waiting,       % waiting | playing | finished
    landlord_cards = []    % 地主牌
}).

%% AI状态记录
-record(ai_state, {
    strategy_model,        % 策略模型
    learning_model,        % 学习模型
    opponent_model,        % 对手模型
    personality,           % aggressive | conservative | balanced
    performance_stats = [] % 性能统计
}).

%% 学习系统状态记录
-record(learning_state, {
    neural_network,        % 深度神经网络模型
    experience_buffer,     % 经验回放缓冲
    model_version,         % 模型版本
    training_stats         % 训练统计
}).

%% 对手模型记录
-record(opponent_model, {
    play_patterns = #{},    % 出牌模式统计
    card_preferences = #{}, % 牌型偏好
    risk_profile = 0.5,    % 风险偏好
    skill_rating = 500,    % 技能评分
    play_history = []      % 历史出牌记录
}).

%% 策略状态记录
-record(strategy_state, {
    current_strategy,      % 当前策略
    performance_metrics,   % 性能指标
    adaptation_rate,       % 适应率
    optimization_history   % 优化历史
}).

%% 游戏管理器状态记录
-record(game_manager_state, {
    game_id,              % 游戏ID
    players,              % 玩家列表
    ai_players,           % AI玩家
    current_state,        % 当前游戏状态
    history               % 游戏历史
}).

%% 牌型记录
-record(card_pattern, {
    type,                 % single | pair | triple | straight | bomb | rocket
    value,                % 主牌值
    length = 1,           % 顺子长度
    extra = []            % 附加牌
}).