-module(cards).
-export([init_cards/0, shuffle_cards/1, deal_cards/1, sort_cards/1]).

%% 初始化一副牌
init_cards() ->
    Colors = ["♠", "♥", "♣", "♦"],
    Numbers = ["3","4","5","6","7","8","9","10","J","Q","K","A","2"],
    Cards = [{Color, Number} || Color <- Colors, Number <- Numbers],
    [{joker, "小王"}, {joker, "大王"}] ++ Cards.

%% 洗牌
shuffle_cards(Cards) ->
    List = [{rand:uniform(), Card} || Card <- Cards],
    [Card || {_, Card} <- lists:sort(List)].

%% 发牌 - 返回{Player1Cards, Player2Cards, Player3Cards, LandlordCards}
deal_cards(Cards) ->
    {First17, Rest} = lists:split(17, Cards),
    {Second17, Rest2} = lists:split(17, Rest),
    {Third17, LandlordCards} = lists:split(17, Rest2),
    {First17, Second17, Third17, LandlordCards}.

%% 排序牌 - 根据大小排序
sort_cards(Cards) ->
    CardValues = [{"3",3}, {"4",4}, {"5",5}, {"6",6}, {"7",7}, {"8",8}, {"9",9}, 
                 {"10",10}, {"J",11}, {"Q",12}, {"K",13}, {"A",14}, {"2",15},
                 {"小王",16}, {"大王",17}],
    lists:sort(
        fun({_, N1}, {_, N2}) ->
            {_, V1} = lists:keyfind(N1, 1, CardValues),
            {_, V2} = lists:keyfind(N2, 1, CardValues),
            V1 =< V2
        end,
        Cards).