%% 在 record state 中添加新的字段
-record(state, {
    name,
    game_pid,
    cards = [],
    score = 0,
    wins = 0,
    losses = 0
}).

%% 添加新的API函数
get_name(PlayerPid) ->
    gen_server:call(PlayerPid, get_name).

get_statistics(PlayerPid) ->
    gen_server:call(PlayerPid, get_statistics).

%% 在 init/1 中初始化积分
init([Name]) ->
    case score_system:get_score(Name) of
        {ok, {Score, Wins, Losses}} ->
            {ok, #state{name = Name, score = Score, wins = Wins, losses = Losses}};
        _ ->
            {ok, #state{name = Name}}
    end.

%% 添加新的处理函数
handle_call(get_name, _From, State) ->
    {reply, {ok, State#state.name}, State};

handle_call(get_statistics, _From, State) ->
    Stats = {State#state.score, State#state.wins, State#state.losses},
    {reply, {ok, Stats}, State};

%% 修改游戏结束处理
handle_cast({game_end, Winner}, State = #state{name = Name}) ->
    Points = calculate_points(Winner, State#state.name),
    GameResult = case Name =:= Winner of
        true -> win;
        false -> loss
    end,
    {ok, {NewScore, NewWins, NewLosses}} = 
        score_system:update_score(Name, GameResult, Points),
    {noreply, State#state{
        score = NewScore,
        wins = NewWins,
        losses = NewLosses
    }}.

%% 添加内部辅助函数
calculate_points(Winner, PlayerName) ->
    case {Winner =:= PlayerName, is_landlord(PlayerName)} of
        {true, true} -> 3;  % 地主赢
        {true, false} -> 2; % 农民赢
        {false, true} -> -3; % 地主输
        {false, false} -> -2 % 农民输
    end.

is_landlord(PlayerName) ->
    %% 根据游戏状态判断是否为地主
    %% 这里需要与 game_server 配合实现
    false.