-module(system_supervisor).
-behaviour(supervisor).

-export([start_link/0, init/1]).
-export([start_system/0, stop_system/0, system_status/0]).

%% 启动整个系统
start_system() ->
    application:ensure_all_started(cardSrv).

%% 停止整个系统
stop_system() ->
    application:stop(cardSrv).

%% 获取系统状态
system_status() ->
    [{supervisor, ?MODULE},
     {children, supervisor:which_children(?MODULE)},
     {memory, erlang:memory()},
     {process_count, erlang:system_info(process_count)}].

start_link() ->
    supervisor:start_link({local, ?MODULE}, ?MODULE, []).

init([]) ->
    SupFlags = #{
        strategy => one_for_one,
        intensity => 10,
        period => 60
    },
    
    Children = [
        #{
            id => game_manager,
            start => {game_manager, start_link, []},
            restart => permanent,
            shutdown => 5000,
            type => worker,
            modules => [game_manager]
        },
        #{
            id => player_manager,
            start => {player_manager, start_link, []},
            restart => permanent,
            shutdown => 5000,
            type => worker,
            modules => [player_manager]
        },
        #{
            id => ai_supervisor,
            start => {ai_supervisor, start_link, []},
            restart => permanent,
            shutdown => 5000,
            type => supervisor,
            modules => [ai_supervisor]
        }
    ],
    
    {ok, {SupFlags, Children}}.